Learn R Programming

tzupdater (version 0.1.5)

get_last_published_tz: get_last_published_tz

Description

Get the name of the latest version available at IANA website.

Usage

get_last_published_tz()

Arguments

Value

Latest IANA tz db version name or Unknown if not found.

Examples

Run this code
# Will return for instance "2019c"
get_last_published_tz()

Run the code above in your browser using DataLab