powered by
Download and compile a tz database from the IANA website and make it active as an option. In case the tz db exists already, do not download again.
install_tz( tgt_version = "2019c", zic_path = NA, target_folder = paste0(tempdir(), "/tzupdater/data/IANA_release"), show_zic_log = FALSE, err_stop = TRUE, activate_tz = TRUE, verbose = TRUE, fail_if_zic_missing = FALSE )
Version to download and compile (eg 2019c, 2019a).
Optional for Windows: path to the zic compiler (if not in C:\Cygwin\usr\sbin)
Optional target folder. Default will be tzupdater/data/IANA_release as in tempdir()
Optional: show logs from the zic compiler (TRUE/FALSE). Default FALSE.
Stop on error (TRUE/FALSE). Default TRUE. Recommanded to TRUE.
Activate the tz database once installed. Default TRUE.
Print additional information to the console TRUE/FALSE. Default TRUE.
Stop execution if zic is missing (default FALSE, will only display a message)
# Install tz database 2019c install_tz("2019c")
Run the code above in your browser using DataLab