powered by
Get the name of the latest version available at IANA website.
get_last_published_tz()
Latest IANA tz db version name or Unknown if not found.
# Will return for instance "2019c" get_last_published_tz()
Run the code above in your browser using DataLab