# Get the latest version available and compile.
# If your tz database is already the latest, do nothing.
install_last_tz()
# Same, but more verbose.
install_last_tz(verbose = TRUE)
# On Windows: install latest tz database, with Cygwin installed in c:\Cygwin.
install_last_tz(zic_path="C:\\Cygwin\\usr\\sbin")
Run the code above in your browser using DataLab